from .notification import Notification
from .notification import notification

__version__ = '0.0.16'

__all__ = ["Notification", "notification"]
